@@ -376,12 +376,16 @@ node_store_add_textbox (NodeStore *self, Textbox *text)
 {
 	g_object_set (G_OBJECT (text), "store", self, NULL);
 	self->textbox = g_list_prepend (self->textbox, text);
+
+	return TRUE;
 }
 
 int
 node_store_remove_textbox (NodeStore *self, Textbox *text)
 {
 	self->textbox = g_list_remove (self->textbox, text);
+
+	return TRUE;
 }
 
 int
@@ -438,8 +442,8 @@ node_store_add_wire (NodeStore *store, Wire *wire)
 
 			_x1 = w_pos.x;
 			_y1 = w_pos.y;
-			_x2 = x1 + w_length.x;
-			_y2 = y1 + w_length.y;
+			_x2 = _x1 + w_length.x;
+			_y2 = _y1 + w_length.y;
 
 			can_join = TRUE;
 			nodes = wire_get_nodes (wire);
@@ -487,8 +491,8 @@ node_store_add_wire (NodeStore *store, Wire *wire)
 
 			_x1 = w_pos.x;
 			_y1 = w_pos.y;
-			_x2 = x1 + w_length.x;
-			_y2 = y1 + w_length.y;
+			_x2 = _x1 + w_length.x;
+			_y2 = _y1 + w_length.y;
 
 			can_join = TRUE;
 			nodes = wire_get_nodes (wire);
@@ -1183,7 +1187,6 @@ node_store_print_labels (NodeStore *store, OreganoPrintContext *opc, ArtDRect *r
 int
 node_store_is_pin_at_pos (NodeStore *store, SheetPos pos)
 {
-	int ret = 0;
 	int num_pins;
 	SheetPos part_pos;
 	GList *p;
@@ -1205,12 +1208,9 @@ node_store_is_pin_at_pos (NodeStore *store, SheetPos pos)
 			y = part_pos.y + pins[i].offset.y;
 
 			if ((x == pos.x) && (y == pos.y)) {
-				ret = 1;
-				/* Fast exit ;-) */
-				goto fast_exit;
+				return 1;
 			}
 		}
 	}
-fast_exit:
-	return ret;
+	return 0;
 }
