@@ -37,6 +37,7 @@
 #include "oregano-config.h"
 #include "load-library.h"
 #include "dialogs.h"
+#include "engine.h"
 
 #define OREGLIB_EXT	"oreglib"
 
@@ -50,9 +51,7 @@ oregano_config_load (void)
 
 	gconf = gconf_client_get_default ();
 
-	oregano.simexec = gconf_client_get_string (gconf, "/apps/oregano/sim_exec",
-		NULL);
-	oregano.simtype = gconf_client_get_string (gconf, "/apps/oregano/sim_type",
+	oregano.engine = gconf_client_get_int (gconf, "/apps/oregano/engine",
 		NULL);
 	oregano.compress_files = gconf_client_get_bool (gconf, "/apps/oregano/compress_files",
 		NULL);
@@ -65,10 +64,8 @@ oregano_config_load (void)
 
 	/* Let's deal with first use -I don't like this- */
 
-	if (!oregano.simexec)
-		oregano.simexec = g_strdup ("oregano_parser.pl");
-	if (!oregano.simtype)
-		oregano.simtype = g_strdup ("gnucap");
+	if ((oregano.engine < 0) || (oregano.engine >= OREGANO_ENGINE_COUNT))
+		oregano.engine = 0;
 }
 
 void
@@ -78,9 +75,7 @@ oregano_config_save (void)
 
 	gconf = gconf_client_get_default ();
 
-	gconf_client_set_string (gconf, "/apps/oregano/sim_exec", oregano.simexec,
-		NULL);
-	gconf_client_set_string (gconf, "/apps/oregano/sim_type", oregano.simtype,
+	gconf_client_set_int (gconf, "/apps/oregano/engine", oregano.engine,
 		NULL);
 	gconf_client_set_bool (gconf, "/apps/oregano/compress_files", oregano.compress_files,
 		NULL);
@@ -103,10 +98,12 @@ oregano_lookup_libraries (Splash *sp)
 	oregano.libraries = NULL;
 	libdir = opendir (OREGANO_LIBRARYDIR);
 
-	/* FIXME: Either handle this in a correct way or (like this) don't allow
-	   changes during run-time... */
-	if (oregano.libraries != NULL)
+	if (libdir == NULL) return;
+
+	if (oregano.libraries != NULL) {
+		closedir (libdir);
 		return;
+	}
 
 	fname = g_build_filename (OREGANO_LIBRARYDIR, "default.oreglib", NULL);
 
@@ -114,13 +111,12 @@ oregano_lookup_libraries (Splash *sp)
 		library = library_parse_xml_file (fname);
 		oregano.libraries = g_list_append (oregano.libraries, library);
 	}
+	g_free (fname);
 
-	if (libdir == NULL) return;
 	while ((libentry=readdir (libdir)) != NULL) {
 		if (is_oregano_library_name (libentry->d_name) &&
 			strcmp (libentry->d_name,"default.oreglib")) {
-			fname = g_build_filename (OREGANO_LIBRARYDIR, libentry->d_name,
-				NULL);
+			fname = g_build_filename (OREGANO_LIBRARYDIR, libentry->d_name, NULL);
 
 			/* do the following only if splash is enabled */
 			if (sp) {
@@ -140,6 +136,7 @@ oregano_lookup_libraries (Splash *sp)
 			g_free(fname);
 		}
 	}
+	closedir (libdir);
 }
 
 /*
