@@ -1,20 +1,23 @@
 /*
  * print.h
  *
- * 
- * Author: 
+ *
+ * Authors:
  *  Richard Hult <rhult@hem.passagen.se>
- * 
- *  http://www.dtek.chalmers.se/~d4hult/oregano/ 
- * 
- * Copyright (C) 1999,2000  Richard Hult 
- * 
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the 
- * License, or (at your option) any later version. 
- * 
- * This program is distributed in the hope that it will be useful, 
+ *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
+ *  Andres de Barbara <adebarbara@fi.uba.ar>
+ *
+ * Web page: http://arrakis.lug.fi.uba.ar/
+ *
+ * Copyright (C) 1999-2001  Richard Hult
+ * Copyright (C) 2003,2004  LUGFI
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
@@ -28,15 +31,18 @@
 #define __PRINT_H
 
 #include <gnome.h>
-#include <libgnomeprint/gnome-printer.h>
 #include <libgnomeprint/gnome-print.h>
 
 typedef struct {
 	GnomePrintContext *ctx;
-	GnomeFont *label_font;
+	GnomeFontFace *label_font;
+	GnomePrintConfig *config;
+	gdouble scale;
+	gdouble lmargin, tmargin, rmargin, bmargin;
+	gdouble width, height;
 } OreganoPrintContext;
 
-void print_schematic (GtkWidget *w, gboolean preview_only);
+void print_schematic (GObject *w, gboolean preview_only);
 void print_draw_ellipse (GnomePrintContext *ctx, ArtPoint *center, gdouble width, gdouble height);
 void print_draw_text (GnomePrintContext *ctx, const gchar *text, ArtPoint *pos);
 
