@@ -33,6 +33,6 @@
 #include <glib.h>
 #include "schematic.h"
 
-gint schematic_save_file (Schematic *sm);
+gint schematic_write_xml (Schematic *sm, GError **error);
 
 #endif
