@@ -37,7 +37,6 @@
 #include <libbonobo-2.0/libbonobo.h>
 #include <sys/time.h>
 
-#include "simulate.h"
 #include "sheet-private.h"
 #include "schematic-view.h"
 #include "schematic.h"
@@ -61,6 +60,7 @@
 #include "part-item.h"
 #include "errors.h"
 #include "node-item.h"
+#include "engine.h"
 
 /* remove: */
 #include "create-wire.h"
@@ -627,8 +627,8 @@ quit_cmd (GtkWidget *widget, SchematicView *sv)
 	copy = g_list_copy (schematic_view_list);
 
 	for (list = copy; list; list = list->next){
-		/* if (schematic_can_close (list->data)) */
-			g_object_unref(list->data);
+		if (can_close (list->data))
+			g_object_unref (list->data);
 	}
 
 	g_list_free (copy);
@@ -659,7 +659,6 @@ static void
 v_clamp_cmd (GtkWidget *widget, SchematicView *sv)
 {
 	LibraryPart *library_part;
-	char *part_name;
 	SheetPos pos;
 	Sheet *sheet;
 	Part *part;
@@ -735,23 +734,13 @@ voltmeter_cmd (GtkWidget *widget, SchematicView *sv)
 	schematic_view_show_voltmeters (sv, sv->priv->show_voltmeters);
 }
 
-#if 0
-static void
-plot_cmd (GtkWidget *widget, SchematicView *sm)
-{
-	g_return_if_fail (sm != NULL);
-
-	plot_show (sv->priv->simulation_data);
-}
-#endif
-
 static void
 netlist_cmd (GtkWidget *widget, SchematicView *sv)
 {
 	Schematic *sm;
 	gchar *netlist_name;
-	gchar *netlist_result;
 	GError *error = 0;
+	OreganoEngine *engine;
 
 	g_return_if_fail (sv != NULL);
 
@@ -762,10 +751,12 @@ netlist_cmd (GtkWidget *widget, SchematicView *sv)
 		return;
 
 	schematic_set_netlist_filename (sm, netlist_name);
-	netlist_result = nl_generate (sm, netlist_name, &error);
+	engine = oregano_engine_factory_create_engine (oregano.engine, sm);
+	oregano_engine_generate_netlist (engine, netlist_name, &error);
 	schematic_view_update_parts (sv);
 
 	g_free (netlist_name);
+	g_object_unref (engine);
 	
 	if (error != NULL) {
 		if (g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_NO_CLAMP) ||
@@ -778,8 +769,6 @@ netlist_cmd (GtkWidget *widget, SchematicView *sv)
 		}
 		return;
 	}
-
-/*	g_free (netlist_result); */
 }
 
 static void
@@ -874,33 +863,9 @@ static void
 simulate_cmd (GtkWidget *widget, SchematicView *sv)
 {
 	Schematic *sm;
-	char *filename;
-	GError *error = 0;
-
-	NodeStore *store;
-	GList *parts;
 
 	sm = sv->priv->schematic;
 
-	store = schematic_get_store (sm);
-	parts = node_store_get_parts (store);
-
-	
-	filename = nl_generate (sm, NULL, &error);
-
-	if (error != NULL) {
-		if (g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_NO_CLAMP) ||
-				g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_NO_GND) ||
-				g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_IO_ERROR)) {
-			oregano_error_with_title (_("Could not create a netlist"), error->message);
-			g_error_free (error);
-		} else {
-			oregano_error (_("An unexpected error has occurred"));
-		}
-		return;
-	}
-
-	schematic_set_netlist_filename (sm, filename);
 	simulation_show (NULL, sv);
 
 	schematic_view_update_parts (sv);
@@ -1115,7 +1080,6 @@ schematic_view_new (Schematic *schematic)
 {
 	SchematicView *sv;
 	SchematicViewPriv *priv;
-	GList *list;
 	GtkAdjustment *vadj, *hadj;
 	GtkWidget *w, *hbox;
 	GtkWidget *toolbar;
@@ -1222,7 +1186,7 @@ schematic_view_new (Schematic *schematic)
 	priv->menu_item_cut = schematic_menu_edit[3].widget;
 	priv->menu_item_copy = schematic_menu_edit[4].widget;
 	priv->menu_item_paste = schematic_menu_edit[5].widget;
-	priv->menu_item_properties = schematic_menu_edit[13].widget;
+	priv->menu_item_properties = schematic_menu_edit[12].widget;
 
 /*	priv->toolbar_item_undo = schematic_standard_toolbar[4].widget;
 	priv->toolbar_item_redo = schematic_standard_toolbar[5].widget;*/
@@ -1240,6 +1204,7 @@ schematic_view_new (Schematic *schematic)
 	priv->toolbar_item_grid = schematic_view_toolbar[1].widget;
 	priv->toolbar_item_part_browser = schematic_view_toolbar[0].widget;
 	
+	gtk_widget_set_sensitive (priv->menu_item_properties, FALSE);
 	/*
 	 * FIXME: remove this when the functions are implemented.
 	 
@@ -1422,6 +1387,7 @@ static void
 item_selection_changed_callback (SheetItem *item, gboolean selected,
 	SchematicView *sv)
 {
+	/* FIXME! : don't touch sheet->priv directly!!! */
 	if (selected) {
 		sv->priv->sheet->priv->selected_objects =
 			g_list_prepend ( sv->priv->sheet->priv->selected_objects, item);
@@ -1429,6 +1395,12 @@ item_selection_changed_callback (SheetItem *item, gboolean selected,
 		sv->priv->sheet->priv->selected_objects =
 			g_list_remove ( sv->priv->sheet->priv->selected_objects, item);
 	}
+
+	if ((g_list_length (sv->priv->sheet->priv->selected_objects) == 1) &&
+		item_data_has_properties (sheet_item_get_data (item)))
+		gtk_widget_set_sensitive (sv->priv->menu_item_properties, TRUE);
+	else
+		gtk_widget_set_sensitive (sv->priv->menu_item_properties, FALSE);
 }
 
 /**
@@ -1527,10 +1499,10 @@ delete_event(GtkWidget *widget, GdkEvent *event, SchematicView *sv)
 static int
 can_close (SchematicView *sv)
 {
-	GtkWidget *dialog, *lb;
+	GtkWidget *dialog;
 	gchar *text, *filename;
-	gint result;
 	GError *error = NULL;
+	gint result;
 
 	if (!schematic_is_dirty (schematic_view_get_schematic (sv)))
 		return TRUE;
@@ -1831,8 +1803,6 @@ data_received (GtkWidget *widget, GdkDragContext *context, gint x, gint y,
 	   SchematicView *sv)
 {
 	gchar **files;
-	GtkTargetEntry *array;
-	guint narray;
 	GError *error = NULL;
 
 	/*
@@ -2052,9 +2022,6 @@ rubberband_timeout_cb (SchematicView *sv)
 	dx = fabs ((x1 - x2) - (x1_old - x2_old));
 	dy = fabs ((y1 - y2) - (y1_old - y2_old));
 	if (dx > 1.0 || dy > 1.0) {
-		/* Adjust points for the selection */
-		double tx, ty;
-
 		/* Save old state */
 		x1_old = x1;
 		y1_old = y1;
@@ -2446,12 +2413,8 @@ log_updated_callback (Schematic *sm, SchematicView *sv)
 void
 schematic_view_log_show (SchematicView *sv, gboolean explicit)
 {
-	GList *log;
-	GtkTextBuffer *buffer;
-	GtkTextIter iter;
 	GtkWidget *w;
 	gchar *msg;
-	gint i = 0;
 	Schematic *sm;
 
 	g_return_if_fail (sv != NULL);
@@ -2522,29 +2485,11 @@ schematic_view_log_show (SchematicView *sv, gboolean explicit)
 		gdk_window_raise (sv->priv->log_window->window);
 	}
 
-	buffer = gtk_text_view_get_buffer (sv->priv->log_text);
+	gtk_text_view_set_buffer (
+		sv->priv->log_text,
+		schematic_get_log_text (sm)
+	);
 
-	/*
-	 * Clear the log before filling it.
-	 */
-	gtk_text_buffer_set_text (buffer, "", -1);
-
-	gtk_text_buffer_get_iter_at_line (buffer, &iter, 0);
-
-	for (log = schematic_get_log_text (sm); log; log = log->next) {
-		/*
-		 * Put the oldest messages at the top.
-		 */
-
-		gtk_text_buffer_insert (buffer, &iter, log->data, -1);
-
-		/*
-		 * Guard against too many messages. Note that
-		 * we always get the 500 latest this way.
-		 */
-		if (i++ > 500)
-			break;
-	}
 
 	gtk_widget_show_all (sv->priv->log_window);
 }
@@ -2579,8 +2524,8 @@ dot_equal (gconstpointer a, gconstpointer b)
 {
 	SheetPos *spa, *spb;
 
-	g_return_if_fail(a!=NULL);
-	g_return_if_fail(b!=NULL);
+	g_return_val_if_fail (a!=NULL, 0);
+	g_return_val_if_fail (b!=NULL, 0);
 
 	spa = (SheetPos *) a;
 	spb = (SheetPos *) b;
@@ -2601,7 +2546,7 @@ dot_equal (gconstpointer a, gconstpointer b)
  * FIXME: solve similar to the connection dots.
  */
 void
-schematic_view_show_op_values (SchematicView *sv, SimEngine *engine)
+schematic_view_show_op_values (SchematicView *sv, OreganoEngine *engine)
 {
 	GList *nodes, *list;
 	NodeStore *store;
@@ -2614,7 +2559,8 @@ schematic_view_show_op_values (SchematicView *sv, SimEngine *engine)
 	g_return_if_fail (sv != NULL);
 	g_return_if_fail (IS_SCHEMATIC_VIEW (sv));
 	g_return_if_fail (engine != NULL);
-	g_return_if_fail (IS_SIM_ENGINE (engine));
+
+	return;
 
 	store = schematic_get_store (sv->priv->schematic);
 
@@ -2625,19 +2571,16 @@ schematic_view_show_op_values (SchematicView *sv, SimEngine *engine)
 	for (list = nodes; list; list = list->next) {
 		node = list->data;
 
-		got = sim_engine_get_op_value (engine,
-			node->netlist_node_name, &value);
+		got = 0; //sim_engine_get_op_value (engine, node->netlist_node_name, &value);
 		if (!got) {
 			tmp = g_strdup_printf ("V(%s)",
 				node->netlist_node_name);
-			got = sim_engine_get_op_value (engine, tmp, &value);
+			//got = sim_engine_get_op_value (engine, tmp, &value);
 		} else
 			tmp = g_strdup (node->netlist_node_name);
 
 		if (got) {
-			/*
-			 * Don't have more than one meter per node.
-			 */
+			/* Don't have more than one meter per node. */
 			if (g_hash_table_lookup (sv->priv->voltmeter_nodes,
 				    tmp) != NULL)
 				continue;
