@@ -40,7 +40,6 @@
 #include "part-property.h"
 #include "load-library.h"
 #include "load-common.h"
-#include "netlist.h"
 #include "part-label.h"
 #include "stock.h"
 #include "dialogs.h"
@@ -584,7 +583,7 @@ prop_dialog_response(GtkWidget *dialog, gint response,
 			prop = props->data;
 			if (g_strcasecmp (prop->name, prop_name) == 0) {
 				if (prop->value) g_free (prop->value);
-				prop_value = g_strdup (prop_value);
+				prop->value = g_strdup (prop_value);
 			}
 		}
 		g_free (prop_name);
@@ -681,42 +680,41 @@ edit_properties_punta (PartItem *item)
 	}
 
 	response = gtk_dialog_run(prop_dialog->dialog);
-	if (response == GTK_RESPONSE_OK) {
-		/* Save properties from GUI */
-		for (properties = part_get_properties (part); properties;
-			properties = properties->next) {
-			Property *prop;
-			prop = properties->data;
 
-			if (prop->name) {
-				if (!g_strcasecmp (prop->name, "internal"))
-					continue;
+	/* Save properties from GUI */
+	for (properties = part_get_properties (part); properties;
+		properties = properties->next) {
+		Property *prop;
+		prop = properties->data;
+
+		if (prop->name) {
+			if (!g_strcasecmp (prop->name, "internal"))
+				continue;
 	
-				if (!g_strcasecmp (prop->name, "type")) {
-					g_free (prop->value);
-					if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio_v))) {
-						prop->value = g_strdup ("v");
-					} else {
-						prop->value = g_strdup ("i");
-					}
-				} else if (!g_strcasecmp (prop->name, "ac_type")) {
-					g_free (prop->value);
-					if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ac_m))) {
-						prop->value = g_strdup ("m");
-					} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ac_i))) {
-						prop->value = g_strdup ("i");
-					} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ac_p))) {
-						prop->value = g_strdup ("p");
-					} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ac_r))) {
-						prop->value = g_strdup ("r");
-					}
-				} else if (!g_strcasecmp (prop->name, "ac_db")) {
-					g_free (prop->value);
-					if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (chk_db)))
-						prop->value = g_strdup ("true");
-					else
-						prop->value = g_strdup ("false");
+			if (!g_strcasecmp (prop->name, "type")) {
+				g_free (prop->value);
+				if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio_v))) {
+					prop->value = g_strdup ("v");
+				} else {
+					prop->value = g_strdup ("i");
 				}
+			} else if (!g_strcasecmp (prop->name, "ac_type")) {
+				g_free (prop->value);
+				if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ac_m))) {
+					prop->value = g_strdup ("m");
+				} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ac_i))) {
+					prop->value = g_strdup ("i");
+				} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ac_p))) {
+					prop->value = g_strdup ("p");
+				} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ac_r))) {
+					prop->value = g_strdup ("r");
+				}
+			} else if (!g_strcasecmp (prop->name, "ac_db")) {
+				g_free (prop->value);
+				if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (chk_db)))
+					prop->value = g_strdup ("true");
+				else
+					prop->value = g_strdup ("false");
 			}
 		}
 	}
@@ -832,9 +830,8 @@ edit_properties (SheetItem *object)
 	gtk_dialog_set_default_response (prop_dialog->dialog, 1);
 
 	response = gtk_dialog_run(prop_dialog->dialog);
-	if (response == GTK_RESPONSE_OK) {
-		prop_dialog_response (GTK_WIDGET (prop_dialog->dialog), response, prop_dialog);
-	}
+
+	prop_dialog_response (GTK_WIDGET (prop_dialog->dialog), response, prop_dialog);
 
 	gtk_widget_destroy (GTK_WIDGET (prop_dialog->dialog));
 }
@@ -935,7 +932,7 @@ part_flipped_callback (ItemData *data, gboolean horizontal,
 	SheetItem *sheet_item)
 {
 	GList *list;
-	GSList *label_items;
+	GSList *label;
 	GtkAnchorType anchor;
 	GnomeCanvasGroup *group;
 	GnomeCanvasItem *canvas_item;
@@ -985,13 +982,13 @@ part_flipped_callback (ItemData *data, gboolean horizontal,
 		anchor = GTK_ANCHOR_NORTH_EAST;
 	}*/
 
-	for (list= item->priv->label_items; list;
-	     list = list->next) {
+	for (label = item->priv->label_items; label; label = label->next) {
 		gnome_canvas_item_set (
-			GNOME_CANVAS_ITEM (label_items->data),
+			GNOME_CANVAS_ITEM (label->data),
 			"anchor", anchor,
 			NULL);
 	}
+
 	/*
 	 * Invalidate the bounding box cache.
 	 */
