@@ -47,8 +47,7 @@
 #include "dialogs.h"
 
 #define NORMAL_COLOR "black"
-#define SELECTED_COLOR "red"
-#define HIGHLIGHT_COLOR "green"
+#define SELECTED_COLOR "green"
 //#define TEXTBOX_FONT "-*-helvetica-medium-r-*-*-*-100-*-*-*-*-*-*"
 #define TEXTBOX_FONT "Arial 10"
 
@@ -665,7 +664,6 @@ edit_textbox (SheetItem *sheet_item)
 	TextboxItemPriv *priv;
 	Textbox *textbox;
 	char *msg, *value;
-	gint response;
 	GladeXML *gui;
 
 	g_return_if_fail (sheet_item != NULL);
@@ -713,10 +711,9 @@ edit_textbox (SheetItem *sheet_item)
 	gtk_dialog_set_default_response (
 		GTK_DIALOG (prop_dialog->dialog), GTK_RESPONSE_OK);
 
-	response = gtk_dialog_run( GTK_DIALOG (prop_dialog->dialog));
-	if (response == GTK_RESPONSE_OK) {
-		edit_dialog_ok(item);
-	}
+	gtk_dialog_run( GTK_DIALOG (prop_dialog->dialog));
+
+	edit_dialog_ok(item);
 
 	/* Clean the dialog */
 	gtk_widget_destroy(GTK_WIDGET(prop_dialog->dialog));
